aboutsummaryrefslogtreecommitdiff
path: root/Carpet/CarpetLib/src/operators.hh
diff options
context:
space:
mode:
Diffstat (limited to 'Carpet/CarpetLib/src/operators.hh')
-rw-r--r--Carpet/CarpetLib/src/operators.hh4
1 files changed, 3 insertions, 1 deletions
diff --git a/Carpet/CarpetLib/src/operators.hh b/Carpet/CarpetLib/src/operators.hh
index 8ecd308a4..07e4e5616 100644
--- a/Carpet/CarpetLib/src/operators.hh
+++ b/Carpet/CarpetLib/src/operators.hh
@@ -9,11 +9,13 @@ enum operator_type
op_none, // do not transport
op_sync, // transport only on the same level
// (error if called between levels)
+ op_restrict, // restrict only, do not prolongate
op_copy, // use simple copying for prolongation
// (needs only one time level)
op_Lagrange, // Lagrange interpolation (standard)
op_ENO, // use ENO stencils (for hydro)
- op_WENO // use WENO stencils (for hydro)
+ op_WENO, // use WENO stencils (for hydro)
+ op_Lagrange_monotone // monotone Lagrange interpolation (for hydro)
};
#endif // OPERATORS_HH